@@ -39,7 +39,8 @@ def floor(q0, out=None, where=True, **kwargs):
 
     Examples:
         >>> q0 = numpoly.variable()
-        >>> numpoly.floor([-1.7*q0, q0-1.5, -0.2, 3.2+1.5*q0, 1.7, 2.0])
+        >>> numpoly.floor([-1.7*q0, q0-1.5, -0.2,
+        ...                3.2+1.5*q0, 1.7, 2.0])
         polynomial([-2.0*q0, q0-2.0, -1.0, q0+3.0, 1.0, 2.0])
 
     """
